/*****************************************************************************
**  This is part of the CTSim program
**  Copyright (C) 1983-2000 Kevin Rosenberg
**
**  $Id: pol.h,v 1.3 2000/05/07 12:46:19 kevin Exp $
**  $Log: pol.h,v $
**  Revision 1.3  2000/05/07 12:46:19  kevin
**  made c++ compatible
**
**  Revision 1.2  2000/04/28 14:14:16  kevin
**  *** empty log message ***
**
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/
#ifndef __H_POL
#define __H_POL

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/* codes for pol_usefile */

#define P_USE_STR  1		/* use string as input source */
#define P_USE_FILE 2		/* use file as input source */

/* codes for pol_int and pol_float */
/* if in reject catagory, get new number from terminal */

#define P_FLTINT   1	/* get a real or integer number */
#define P_BFLTINT  2	/* get a real or integer number, clip against bounds */
#define P_CBFLTINT 3	/* get real or int, reject if outside bounds */

#define P_FLT	   4	/* get a real number */
#define P_BFLT     5	/* get a real, clip against bounds */
#define P_CBFLT    6	/* get a floating, reject if outside bounds */

#define P_INT	   7	/* get a integer number */
#define P_BINT     8	/* get a integer, clip against bounds */
#define P_CBINT    9	/* get a integer, reject if outside bounds */

#define LETTER   'a'
#define DIGIT    '0'

#define MAXTOK	 200		/* maximum length of a token */
#define MAXLINE  255
#define MAXIDENT  20
#define MAXSKIPWORD 20
#define MAXSKIPCHAR 20

#define MIN_INT	-32768
#define MAX_INT  32767

/* token types */

#define TT_STRING	 1		/* string token */
#define TT_INT		 2		/* integer token */
#define TT_REAL		 3		/* floating point token */
#define TT_ALPHA	 4		/* alphabetic token */
#define TT_ALPNUM	 5		/* alphanumeric token */
#define TT_NUMALPHA	 6
#define TT_SPECLCHAR	 7

#define TT_EOF		 8		/* end of file reached */
#define TT_ERROR	 9		/* error in token, caused by call to wrong */
					/*  type of token reader */
#define TT_BLANK	10		/* white space token.  pol_tok() skips these */
#define TT_USERTOK	11		/* user defined token */

struct symlist {
	char *name;
	int code;
	struct symlist *next;
};

typedef struct symlist SYMBOL;

struct token_st {
    int ready;				/* TRUE if token is ready */
    char tokstr[MAXTOK+1];		/* token string */
    int type;				/* type of token 'TT_' */
    int code;				/* holds code for user defined tokens */
    double fnum;			/* real value of token */
    int inum;				/* integer value of token */
};

typedef struct token_st TOKEN;

/* pol.c */
void pol_init(void);
void pol_skpword(char *w);
void pol_skpchar(char *s);
int pol_install(char *str, int code);
int pol_word(char *search, int nlet);
int pol_usertok(char *str, int *code);
int pol_string(char *str);
int pol_integer(int *n, int typecode, int boundcode, int bb1, int bb2);
int pol_float(double *n, double typecode, double boundcode, double bb1, double bb2);
int pol_skip(void);
void pol_reader(void);
void gettext(char *str, int lim);
void pol_usefile(int source, char *fn);
void pol_closefile(void);
int pol_lookchar(void);
int pol_inchar(void);
void pol_ungetch(int c);
int get_inputline(FILE *fp);
void set_inputline(char *line);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif
